@@ -37,16 +37,16 @@ class Dataset(BaseType):
     Attributes:
         id (int): The Dataset id
         name (str): Dataset name
-        rowCount (int): Number of rows in the dataset
+        row_count (int): Number of rows in the dataset
         permissions (str): Permissions on the dataset
-        files (List[str]): Names of the file(s) included in the dataset
+        files (List[Datafile]): Names of the file(s) included in the dataset
         labelsets (List[LabelSet]): LabelSets associated with this dataset
         datacolumns (List[DataColumn]): DataColumn(s) of the dataset
     """
 
     id: int
     name: str
-    rowCount: int
+    row_count: int
     status: str
     permissions: str
     files: List[Datafile]
@@ -57,4 +57,4 @@ class Dataset(BaseType):
         return next(l for l in self.labelsets if l.name == name)
 
     def datacolumn_by_name(self, name: str) -> DataColumn:
-        return next(l for l in self.datacolumns if l.name == name)
\ No newline at end of file
+        return next(l for l in self.datacolumns if l.name == name)
